==> neo4j-server-5.25.1-sources.jar: org/neo4j/server/rest/web/ClacksFilter.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.server.rest.web;

import java.io.IOException;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletResponse;

/**
 * Filter that appends the X-Clacks-Overhead header to the response. RIP Richard Macaskill.
 */
public class ClacksFilter extends AbstractFilter {

    public static String X_CLACKS_OVERHEAD_HEADER = "X-Clacks-Overhead";

    private final String clacksNames;

    public ClacksFilter(String clacksNames) {
        this.clacksNames = clacksNames;
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
            throws IOException, ServletException {
        HttpServletResponse servletResponse = (HttpServletResponse) response;
        servletResponse.addHeader(X_CLACKS_OVERHEAD_HEADER, "GNU " + clacksNames);
        chain.doFilter(request, response);
    }
}

==> neo4j-server-2025.07.1-sources.jar: org/neo4j/server/rest/web/ClacksFilter.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.server.rest.web;

import java.io.IOException;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletResponse;

/**
 * Filter that appends the X-Clacks-Overhead header to the response. RIP Richard Macaskill.
 */
public class ClacksFilter extends AbstractFilter {

    public static final String X_CLACKS_OVERHEAD_HEADER = "X-Clacks-Overhead";

    private final String clacksNames;

    public ClacksFilter(String clacksNames) {
        this.clacksNames = clacksNames;
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
            throws IOException, ServletException {
        HttpServletResponse servletResponse = (HttpServletResponse) response;
        servletResponse.addHeader(X_CLACKS_OVERHEAD_HEADER, "GNU " + clacksNames);
        chain.doFilter(request, response);
    }
}
